@@ -1,23 +1,29 @@
-from dataclasses import dataclass
-from typing import Awaitable, Callable, Optional, Union
-import inspect
 import ast
+import inspect
 import os
+from dataclasses import dataclass
+from typing import Callable, Optional
+
 from . import globals
 
+
 @dataclass
 class Config():
     # NOTE: should be in sync with ui.run arguments
-    host: str = '0.0.0.0'
-    port: int = 8080
+    host: str = os.environ.get('HOST', '0.0.0.0')
+    port: int = int(os.environ.get('PORT', '8080'))
     title: str = 'NiceGUI'
     favicon: str = 'favicon.ico'
     dark: Optional[bool] = False
     reload: bool = True
     show: bool = True
-    on_connect: Optional[Union[Callable, Awaitable]] = None
+    on_connect: Optional[Callable] = None
     uvicorn_logging_level: str = 'warning'
+    uvicorn_reload_dirs: str = '.'
+    uvicorn_reload_includes: str = '*.py'
+    uvicorn_reload_excludes: str = '.*, .py[cod], .sw.*, ~*'
     main_page_classes: str = 'q-ma-md column items-start'
+    binding_refresh_interval: float = 0.1
     interactive: bool = False
 
 
@@ -27,6 +33,8 @@ excluded_endings = (
     'runpy.py',
     os.path.join('debugpy', 'server', 'cli.py'),
     os.path.join('debugpy', '__main__.py'),
+    'pydevd.py',
+    '_pydev_execfile.py',
 )
 for f in reversed(inspect.stack()):
     if not any(f.filename.endswith(ending) for ending in excluded_endings):
