@@ -1,18 +1,16 @@
-from typing import Awaitable, Callable, Optional, Union
+from typing import Callable, Optional
+
 import justpy as jp
 
-from ..binding import bind_from, bind_to, BindableProperty
+from ..binding import BindableProperty, bind_from, bind_to
 from ..events import ClickEventArguments, handle_event
 from .element import Element
 
+
 class Button(Element):
     text = BindableProperty()
 
-    def __init__(self,
-                 text: str = '',
-                 *,
-                 on_click: Optional[Union[Callable, Awaitable]] = None,
-                 ):
+    def __init__(self, text: str = '', *, on_click: Optional[Callable] = None):
         """Button Element
 
         :param text: the label of the button
@@ -25,9 +23,9 @@ class Button(Element):
         self.text = text
         self.bind_text_to(self.view, 'label')
 
-        def process_event(view, event):
+        def process_event(view, event) -> Optional[bool]:
             socket = event.get('websocket')
-            handle_event(on_click, ClickEventArguments(sender=self, socket=socket), update=self.parent_view)
+            return handle_event(on_click, ClickEventArguments(sender=self, socket=socket), update=self.parent_view)
 
         view.on('click', process_event)
 
