@@ -1,15 +1,13 @@
-from typing import Awaitable, Callable, Optional, Union
+from typing import Callable, Optional
+
 import justpy as jp
+
 from .bool_element import BoolElement
 
+
 class Checkbox(BoolElement):
 
-    def __init__(self,
-                 text: str = '',
-                 *,
-                 value: bool = False,
-                 on_change: Optional[Union[Callable, Awaitable]] = None,
-                 ):
+    def __init__(self, text: str = '', *, value: bool = False, on_change: Optional[Callable] = None):
         """Checkbox Element
 
         :param text: the label to display next to the checkbox
