@@ -1,16 +1,14 @@
+from typing import Callable, Optional
+
 import justpy as jp
-from typing import Awaitable, Callable, Optional, Union
+
 from .string_element import StringElement
 
+
 class Input(StringElement):
 
-    def __init__(self,
-                 label: str = None,
-                 *,
-                 placeholder: str = None,
-                 value: str = '',
-                 on_change: Optional[Union[Callable, Awaitable]] = None,
-                 ):
+    def __init__(self, label: str = None, *,
+                 placeholder: str = None, value: str = '', on_change: Optional[Callable] = None):
         """Text Input Element
 
         :param label: displayed label for the text input
@@ -23,6 +21,7 @@ class Input(StringElement):
             placeholder=placeholder,
             value=value,
             change=self.handle_change,
+            disable_input_event=True,
             temp=False,
         )
 
