@@ -1,12 +1,13 @@
 import traceback
-from typing import Awaitable, Callable, Dict, Optional, Union
+from typing import Callable, Dict, Optional
 
-from ..events import KeyEventArguments, KeyboardAction, KeyboardKey, KeyboardModifiers, handle_event
+from ..events import KeyboardAction, KeyboardKey, KeyboardModifiers, KeyEventArguments, handle_event
 from .custom_view import CustomView
 from .element import Element
 
 CustomView.use(__file__)
 
+
 class KeyboardView(CustomView):
 
     def __init__(self, on_key: Callable, repeating: bool):
@@ -18,18 +19,13 @@ class KeyboardView(CustomView):
 
 class Keyboard(Element):
 
-    def __init__(self,
-                 *,
-                 on_key: Optional[Union[Callable, Awaitable]] = None,
-                 active: bool = True,
-                 repeating: bool = True,
-                 ):
+    def __init__(self, *, on_key: Optional[Callable] = None, active: bool = True, repeating: bool = True):
         """
         Keyboard
 
         Adds global keyboard event tracking.
 
-        :param handle_keys: callback to be executed when keyboard events occur.
+        :param on_key: callback to be executed when keyboard events occur.
         :param active: boolean flag indicating whether the callback should be executed or not (default: `True`)
         :param repeating: boolean flag indicating whether held keys should be sent repeatedly (default: `True`)
         """
@@ -37,9 +33,9 @@ class Keyboard(Element):
         self.active = active
         self.key_handler = on_key
 
-    def handle_key(self, msg: Dict):
+    def handle_key(self, msg: Dict) -> Optional[bool]:
         if not self.active:
-            return
+            return False
 
         try:
             action = KeyboardAction(
@@ -59,7 +55,13 @@ class Keyboard(Element):
                 code=msg.key_data.code,
                 location=msg.key_data.location,
             )
-            arguments = KeyEventArguments(sender=self, action=action, modifiers=modifiers, key=key)
-            handle_event(self.key_handler, arguments, update=self.parent_view)
+            arguments = KeyEventArguments(
+                sender=self,
+                socket=msg.websocket,
+                action=action,
+                modifiers=modifiers,
+                key=key
+            )
+            return handle_event(self.key_handler, arguments, update=self.parent_view)
         except Exception:
             traceback.print_exc()
