@@ -1,4 +1,5 @@
-from typing import Awaitable, Callable, Optional, Union
+from typing import Callable, Optional
+
 import justpy as jp
 
 from ..events import ClickEventArguments, handle_event
@@ -7,12 +8,7 @@ from .element import Element
 
 class MenuItem(Element):
 
-    def __init__(self,
-                 text: str = '',
-                 on_click: Optional[Union[Callable, Awaitable]] = None,
-                 *,
-                 auto_close: bool = True,
-                 ):
+    def __init__(self, text: str = '', on_click: Optional[Callable] = None, *, auto_close: bool = True):
         """Menu Item Element
 
         A menu item to be added to a menu.
@@ -23,11 +19,13 @@ class MenuItem(Element):
         """
         view = jp.QItem(text=text, clickable=True, temp=False)
 
-        def handle_click(*_):
-            handle_event(on_click, ClickEventArguments(sender=self), update=self.parent_view)
+        def handle_click(view, event) -> Optional[bool]:
+            socket = event.get('websocket')
+            result = handle_event(on_click, ClickEventArguments(sender=self, socket=socket), update=self.parent_view)
             if auto_close:
                 assert isinstance(self.parent_view, jp.QMenu)
                 self.parent_view.value = False
+            return result
 
         view.on('click', handle_click)
 
