@@ -1,17 +1,15 @@
+from typing import Callable, Dict, Optional
+
 import justpy as jp
-from typing import Awaitable, Callable, Optional, Union
+
 from .float_element import FloatElement
 
+
 class Number(FloatElement):
 
-    def __init__(self,
-                 label: str = None,
-                 *,
-                 placeholder: str = None,
-                 value: float = None,
-                 format: str = None,
-                 on_change: Optional[Union[Callable, Awaitable]] = None,
-                 ):
+    def __init__(
+            self, label: str = None, *,
+            placeholder: str = None, value: float = None, format: str = None, on_change: Optional[Callable] = None):
         """Number Input Element
 
         :param label: displayed name for the number input
@@ -25,12 +23,13 @@ class Number(FloatElement):
             label=label,
             placeholder=placeholder,
             change=self.handle_change,
+            disable_input_event=True,
             temp=False,
         )
 
         super().__init__(view, value=value, format=format, on_change=on_change)
 
-    def handle_change(self, msg):
+    def handle_change(self, msg: Dict):
         msg['value'] = float(msg['value'])
 
         return super().handle_change(msg)
