@@ -1,5 +1,7 @@
 var scene;
+var look_at;
 var camera;
+var camera_tween;
 var orbitControls;
 var texture_loader = new THREE.TextureLoader();
 var stl_loader = new THREE.STLLoader();
@@ -70,7 +72,9 @@ Vue.component("scene", {
     const width = this.$props.jp_props.options.width;
     const height = this.$props.jp_props.options.height;
 
+    look_at = new THREE.Vector3(0, 0, 0);
     camera = new THREE.PerspectiveCamera(75, width / height, 0.1, 1000);
+    camera.lookAt(look_at);
     camera.up = new THREE.Vector3(0, 0, 1);
     camera.position.set(0, -3, 5);
 
@@ -105,6 +109,7 @@ Vue.component("scene", {
 
     const render = function () {
       requestAnimationFrame(() => setTimeout(() => render(), 1000 / 20));
+      TWEEN.update();
       renderer.render(scene, camera);
     };
     render();
@@ -182,12 +187,29 @@ Vue.component("scene", {
         const geometry = texture_geometry(coords);
         const material = texture_material(texture_loader.load(url));
         mesh = new THREE.Mesh(geometry, material);
+      } else if (type == "spot_light") {
+        mesh = new THREE.Group();
+        const light = new THREE.SpotLight(...args);
+        light.position.set(0, 0, 0);
+        light.target = new THREE.Object3D();
+        light.target.position.set(1, 0, 0);
+        mesh.add(light);
+        mesh.add(light.target);
       } else {
         let geometry;
         const wireframe = args.pop();
         if (type == "box") geometry = new THREE.BoxGeometry(...args);
         if (type == "sphere") geometry = new THREE.SphereGeometry(...args);
         if (type == "cylinder") geometry = new THREE.CylinderGeometry(...args);
+        if (type == "ring") geometry = new THREE.RingGeometry(...args);
+        if (type == "quadratic_bezier_tube") {
+          const curve = new THREE.QuadraticBezierCurve3(
+            new THREE.Vector3(...args[0]),
+            new THREE.Vector3(...args[1]),
+            new THREE.Vector3(...args[2])
+          );
+          geometry = new THREE.TubeGeometry(curve, ...args.slice(3));
+        }
         if (type == "extrusion") {
           const shape = new THREE.Shape();
           const outline = args[0];
@@ -218,11 +240,14 @@ Vue.component("scene", {
       objects.set(id, mesh);
       objects.get(parent_id).add(objects.get(id));
     },
-    material(object_id, color, opacity) {
+    material(object_id, color, opacity, side) {
       const material = objects.get(object_id).material;
       if (!material) return;
       material.color.set(color);
       material.opacity = opacity;
+      if (side == "front") material.side = THREE.FrontSide;
+      else if (side == "back") material.side = THREE.BackSide;
+      else material.side = THREE.DoubleSide;
     },
     move(object_id, x, y, z) {
       objects.get(object_id).position.set(x, y, z);
@@ -238,6 +263,9 @@ Vue.component("scene", {
       );
       objects.get(object_id).rotation.setFromRotationMatrix(R4.transpose());
     },
+    visible(object_id, value) {
+      objects.get(object_id).visible = value;
+    },
     delete(object_id) {
       objects.get(object_id).removeFromParent();
       objects.delete(object_id);
@@ -256,6 +284,52 @@ Vue.component("scene", {
     set_texture_coordinates(object_id, coords) {
       objects.get(object_id).geometry = texture_geometry(coords);
     },
+    move_camera(
+      x,
+      y,
+      z,
+      look_at_x,
+      look_at_y,
+      look_at_z,
+      up_x,
+      up_y,
+      up_z,
+      duration
+    ) {
+      if (camera_tween) camera_tween.stop();
+      camera_tween = new TWEEN.Tween([
+        camera.position.x,
+        camera.position.y,
+        camera.position.z,
+        camera.up.x,
+        camera.up.y,
+        camera.up.z,
+        look_at.x,
+        look_at.y,
+        look_at.z,
+      ])
+        .to(
+          [
+            x === null ? camera.position.x : x,
+            y === null ? camera.position.y : y,
+            z === null ? camera.position.z : z,
+            up_x === null ? camera.up.x : up_x,
+            up_y === null ? camera.up.y : up_y,
+            up_z === null ? camera.up.z : up_z,
+            look_at_x === null ? look_at.x : look_at_x,
+            look_at_y === null ? look_at.y : look_at_y,
+            look_at_z === null ? look_at.z : look_at_z,
+          ],
+          duration * 1000
+        )
+        .onUpdate((p) => {
+          camera.position.set(p[0], p[1], p[2]);
+          camera.up.set(p[3], p[4], p[5]); // NOTE: before calling lookAt
+          look_at.set(p[6], p[7], p[8]);
+          camera.lookAt(p[6], p[7], p[8]);
+        })
+        .start();
+    },
   },
 
   props: {
