@@ -1,15 +1,13 @@
+from typing import Any, Callable, Dict, List, Optional, Union
+
 import justpy as jp
-from typing import Awaitable, Callable, Dict, List, Optional, Union
+
 from .choice_element import ChoiceElement
 
+
 class Toggle(ChoiceElement):
 
-    def __init__(self,
-                 options: Union[List, Dict],
-                 *,
-                 value: any = None,
-                 on_change: Optional[Union[Callable, Awaitable]] = None,
-                 ):
+    def __init__(self, options: Union[List, Dict], *, value: Any = None, on_change: Optional[Callable] = None):
         """Toggle Element
 
         :param options: a list ['value1', ...] or dictionary `{'value1':'label1', ...}` specifying the options
