@@ -1,22 +1,19 @@
-import justpy as jp
-from typing import Any, Awaitable, Callable, Optional, Union
+from typing import Any, Callable, Dict, Optional
 
+import justpy as jp
+
+from ..binding import BindableProperty, bind_from, bind_to
 from ..events import ValueChangeEventArguments, handle_event
-from ..binding import bind_from, bind_to, BindableProperty
 from .element import Element
 
+
 class ValueElement(Element):
     value = BindableProperty(
         on_change=lambda sender, value: handle_event(sender.change_handler,
                                                      ValueChangeEventArguments(sender=sender, value=value),
                                                      update=sender.parent_view))
 
-    def __init__(self,
-                 view: jp.HTMLBaseComponent,
-                 *,
-                 value: Any,
-                 on_change: Optional[Union[Callable, Awaitable]],
-                 ):
+    def __init__(self, view: jp.HTMLBaseComponent, *, value: Any, on_change: Optional[Callable]):
         super().__init__(view)
 
         self.change_handler = on_change
@@ -26,7 +23,7 @@ class ValueElement(Element):
     def value_to_view(self, value):
         return value
 
-    def handle_change(self, msg):
+    def handle_change(self, msg: Dict):
         self.value = msg['value']
 
     def bind_value_to(self, target_object, target_name, *, forward=lambda x: x):
