@@ -1,46 +1,59 @@
-import asyncio
+import traceback
 from inspect import signature
+from typing import Any, Callable, List, Optional
+
 from justpy.htmlcomponents import HTMLBaseComponent
 from pydantic import BaseModel
-import traceback
-from typing import Any, Awaitable, Callable, List, Optional, Union
 from starlette.websockets import WebSocket
 
 from .elements.element import Element
+from .helpers import is_coroutine
 from .task_logger import create_task
 
+
 class EventArguments(BaseModel):
     class Config:
         arbitrary_types_allowed = True
     sender: Element
     socket: Optional[WebSocket]
 
+
 class ClickEventArguments(EventArguments):
     pass
 
+
+class ColorPickEventArguments(EventArguments):
+    color: str
+
+
 class MouseEventArguments(EventArguments):
     type: str
     image_x: float
     image_y: float
 
+
 class UploadEventArguments(EventArguments):
     files: List[bytes]
 
+
 class ValueChangeEventArguments(EventArguments):
     value: Any
 
+
 class KeyboardAction(BaseModel):
     keypress: bool
     keydown: bool
     keyup: bool
     repeat: bool
 
+
 class KeyboardModifiers(BaseModel):
     alt: bool
     ctrl: bool
     meta: bool
     shift: bool
 
+
 class KeyboardKey(BaseModel):
     name: str
     code: str
@@ -197,6 +210,7 @@ class KeyboardKey(BaseModel):
     def f12(self) -> bool:
         return self.name == 'F12'
 
+
 class KeyEventArguments(EventArguments):
     class Config:
         arbitrary_types_allowed = True
@@ -205,16 +219,14 @@ class KeyEventArguments(EventArguments):
     modifiers: KeyboardModifiers
 
 
-def handle_event(handler: Optional[Union[Callable, Awaitable]],
-                 arguments: EventArguments,
-                 *,
-                 update: Optional[HTMLBaseComponent] = None):
+def handle_event(handler: Optional[Callable], arguments: EventArguments, *,
+                 update: Optional[HTMLBaseComponent] = None) -> Optional[bool]:
     try:
         if handler is None:
-            return
+            return False
         no_arguments = not signature(handler).parameters
         result = handler() if no_arguments else handler(arguments)
-        if asyncio.iscoroutinefunction(handler):
+        if is_coroutine(handler):
             async def async_handler():
                 try:
                     await result
@@ -225,6 +237,6 @@ def handle_event(handler: Optional[Union[Callable, Awaitable]],
             create_task(async_handler(), name=str(handler))
             return False
         else:
-            return result
+            return False if result == False else None
     except Exception:
         traceback.print_exc()
