@@ -1,12 +1,13 @@
 #!/usr/bin/env python3
+# isort:skip_file
 from typing import Awaitable, Callable
 
 from .ui import Ui  # NOTE: before justpy
 import justpy as jp
-from .timer import Timer
-from . import globals
-from . import binding
+
+from . import binding, globals
 from .task_logger import create_task
+from .timer import Timer
 
 
 @jp.app.on_event('startup')
@@ -17,18 +18,21 @@ def startup():
     [safe_invoke(t) for t in Ui.startup_tasks if isinstance(t, Callable)]
     jp.run_task(binding.loop())
 
+
 @jp.app.on_event('shutdown')
 def shutdown():
     [create_task(t, name='shutdown task') for t in Ui.shutdown_tasks if isinstance(t, Awaitable)]
     [safe_invoke(t) for t in Ui.shutdown_tasks if isinstance(t, Callable)]
     [t.cancel() for t in globals.tasks]
 
+
 def safe_invoke(func: Callable):
     try:
         func()
     except:
         globals.log.exception(f'could not invoke {func}')
 
+
 app = globals.app = jp.app
 ui = Ui()
 
