@@ -1,29 +1,46 @@
-from typing import Awaitable, Callable, Optional, Union
 import inspect
+import os
 import sys
 import webbrowser
+from typing import Callable, Optional
+
 import uvicorn
+
 from . import globals
 
 if not globals.config.interactive and globals.config.reload and not inspect.stack()[-2].filename.endswith('spawn.py'):
 
     if globals.config.show:
         webbrowser.open(f'http://{globals.config.host}:{globals.config.port}/')
-    uvicorn.run('nicegui:app', host=globals.config.host, port=globals.config.port, lifespan='on', reload=True,
-                log_level=globals.config.uvicorn_logging_level)
+    uvicorn.run(
+        'nicegui:app',
+        host=globals.config.host,
+        port=globals.config.port,
+        lifespan='on',
+        reload=True,
+        reload_includes=globals.config.uvicorn_reload_includes,
+        reload_excludes=globals.config.uvicorn_reload_excludes,
+        reload_dirs=globals.config.uvicorn_reload_dirs,
+        log_level=globals.config.uvicorn_logging_level,
+    )
     sys.exit()
 
+
 def run(self, *,
-        host: str = '0.0.0.0',
-        port: int = 8080,
+        host: str = os.environ.get('HOST', '0.0.0.0'),
+        port: int = int(os.environ.get('PORT', '8080')),
         title: str = 'NiceGUI',
         favicon: str = 'favicon.ico',
         dark: Optional[bool] = False,
         reload: bool = True,
         show: bool = True,
-        on_connect: Optional[Union[Callable, Awaitable]] = None,
+        on_connect: Optional[Callable] = None,
         uvicorn_logging_level: str = 'warning',
+        uvicorn_reload_dirs: str = '.',
+        uvicorn_reload_includes: str = '*.py',
+        uvicorn_reload_excludes: str = '.*, .py[cod], .sw.*, ~*',
         main_page_classes: str = 'q-ma-md column items-start',
+        binding_refresh_interval: float = 0.1,
         ):
 
     if globals.config.interactive or reload == False:  # NOTE: if reload == True we already started uvicorn above
