@@ -1,21 +1,23 @@
 import asyncio
 import time
 import traceback
-from typing import Awaitable, Callable, List, Union
 from collections import namedtuple
+from typing import Callable, List
 
 from .binding import BindableProperty
 from .globals import tasks, view_stack
+from .helpers import is_coroutine
 from .task_logger import create_task
 
 NamedCoroutine = namedtuple('NamedCoroutine', ['name', 'coro'])
 
+
 class Timer:
     prepared_coroutines: List[NamedCoroutine] = []
 
     active = BindableProperty()
 
-    def __init__(self, interval: float, callback: Union[Callable, Awaitable], *, active: bool = True, once: bool = False):
+    def __init__(self, interval: float, callback: Callable, *, active: bool = True, once: bool = False):
         """Timer
 
         One major drive behind the creation of NiceGUI was the necessity to have a simple approach to update the interface in regular intervals, for example to show a graph with incomming measurements.
@@ -33,7 +35,7 @@ class Timer:
 
         async def do_callback():
             try:
-                if asyncio.iscoroutinefunction(callback):
+                if is_coroutine(callback):
                     return await callback()
                 else:
                     return callback()
